Welcome to manipylator’s documentation! — manipylator 0.1rc documentation

# Welcome to manipylator’s documentation!

Manipylator is Python-based controller used to run a motorized manipulator through a user-friendly graphical interface. This package offers several mechanical assays to physically manipulate a sample. In particular, Manipylator provides in real time controller to exert controlled forces through a cantilever-based force sensor and actuator.

Manipylator currently supports PI ([Physik Instrumente](https://www.physikinstrumente.com/en/)) motorized stages to drive the manipulator.

## User Guide

Contents:

- User Guide

# Indices and tables

- Index

- Module Index

- Search Page